summaryrefslogtreecommitdiffstats
path: root/vendor/github.com/shazow/ssh-chat/sshd/auth.go
diff options
context:
space:
mode:
authorWim <wim@42.be>2019-01-31 17:06:36 +0100
committerWim <wim@42.be>2019-01-31 17:06:36 +0100
commitc81c0dd22a7779148c4890cfd4bbf490054f06f1 (patch)
tree06ce6fcdc8f3a2278a2f3050ba42088dd2e64485 /vendor/github.com/shazow/ssh-chat/sshd/auth.go
parentf8a1ab4622a5b833282e9ee42f382451d17c1a06 (diff)
downloadmatterbridge-msglm-c81c0dd22a7779148c4890cfd4bbf490054f06f1.tar.gz
matterbridge-msglm-c81c0dd22a7779148c4890cfd4bbf490054f06f1.tar.bz2
matterbridge-msglm-c81c0dd22a7779148c4890cfd4bbf490054f06f1.zip
Update vendor, move to labstack/echo/v4 Fixes #698
Diffstat (limited to 'vendor/github.com/shazow/ssh-chat/sshd/auth.go')
-rw-r--r--vendor/github.com/shazow/ssh-chat/sshd/auth.go11
1 files changed, 6 insertions, 5 deletions
diff --git a/vendor/github.com/shazow/ssh-chat/sshd/auth.go b/vendor/github.com/shazow/ssh-chat/sshd/auth.go
index 2fc86fa8..afa7271a 100644
--- a/vendor/github.com/shazow/ssh-chat/sshd/auth.go
+++ b/vendor/github.com/shazow/ssh-chat/sshd/auth.go
@@ -6,6 +6,7 @@ import (
"errors"
"net"
+ "github.com/shazow/ssh-chat/internal/sanitize"
"golang.org/x/crypto/ssh"
)
@@ -13,8 +14,8 @@ import (
type Auth interface {
// Whether to allow connections without a public key.
AllowAnonymous() bool
- // Given address and public key, return if the connection should be permitted.
- Check(net.Addr, ssh.PublicKey) (bool, error)
+ // Given address and public key and client agent string, returns nil if the connection should be allowed.
+ Check(net.Addr, ssh.PublicKey, string) error
}
// MakeAuth makes an ssh.ServerConfig which performs authentication against an Auth implementation.
@@ -23,8 +24,8 @@ func MakeAuth(auth Auth) *ssh.ServerConfig {
NoClientAuth: false,
// Auth-related things should be constant-time to avoid timing attacks.
PublicKeyCallback: func(conn ssh.ConnMetadata, key ssh.PublicKey) (*ssh.Permissions, error) {
- ok, err := auth.Check(conn.RemoteAddr(), key)
- if !ok {
+ err := auth.Check(conn.RemoteAddr(), key, sanitize.Data(string(conn.ClientVersion()), 64))
+ if err != nil {
return nil, err
}
perm := &ssh.Permissions{Extensions: map[string]string{
@@ -36,7 +37,7 @@ func MakeAuth(auth Auth) *ssh.ServerConfig {
if !auth.AllowAnonymous() {
return nil, errors.New("public key authentication required")
}
- _, err := auth.Check(conn.RemoteAddr(), nil)
+ err := auth.Check(conn.RemoteAddr(), nil, sanitize.Data(string(conn.ClientVersion()), 64))
return nil, err
},
}